==> nextcloud-32.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/workflowengine/l10n/en_GB.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "The given operator is invalid",
    "The given regular expression is invalid" : "The given regular expression is invalid",
    "The given file size is invalid" : "The given file size is invalid",
    "The given tag id is invalid" : "The given tag id is invalid",
    "The given IP range is invalid" : "The given IP range is invalid",
    "The given IP range is not valid for IPv4" : "The given IP range is not valid for IPv4",
    "The given IP range is not valid for IPv6" : "The given IP range is not valid for IPv6",
    "The given time span is invalid" : "The given time span is invalid",
    "The given start time is invalid" : "The given start time is invalid",
    "The given end time is invalid" : "The given end time is invalid",
    "The given group does not exist" : "The given group does not exist",
    "File" : "File",
    "File created" : "File created",
    "File updated" : "File updated",
    "File renamed" : "File renamed",
    "File deleted" : "File deleted",
    "File accessed" : "File accessed",
    "File copied" : "File copied",
    "Tag assigned" : "Tag assigned",
    "Someone" : "Someone",
    "%s created %s" : "%s created %s",
    "%s modified %s" : "%s modified %s",
    "%s deleted %s" : "%s deleted %s",
    "%s accessed %s" : "%s accessed %s",
    "%s renamed %s" : "%s renamed %s",
    "%s copied %s" : "%s copied %s",
    "%s assigned %s to %s" : "%s assigned %s to %s",
    "Operation #%s does not exist" : "Operation #%s does not exist",
    "Entity %s does not exist" : "Entity %s does not exist",
    "Entity %s is invalid" : "Entity %s is invalid",
    "No events are chosen." : "No events are chosen.",
    "Entity %s has no event %s" : "Entity %s has no event %s",
    "Operation %s does not exist" : "Operation %s does not exist",
    "Operation %s is invalid" : "Operation %s is invalid",
    "At least one check needs to be provided" : "At least one check needs to be provided",
    "The provided operation data is too long" : "The provided operation data is too long",
    "Invalid check provided" : "Invalid check provided",
    "Check %s does not exist" : "Check %s does not exist",
    "Check %s is invalid" : "Check %s is invalid",
    "Check %s is not allowed with this entity" : "Check %s is not allowed with this entity",
    "The provided check value is too long" : "The provided check value is too long",
    "Check #%s does not exist" : "Check #%s does not exist",
    "Check %s is invalid or does not exist" : "Check %s is invalid or does not exist",
    "Flow" : "Flow",
    "Nextcloud workflow engine" : "Nextcloud workflow engine",
    "Select a filter" : "Select a filter",
    "Select a comparator" : "Select a comparator",
    "Remove filter" : "Remove filter",
    "Audio" : "Audio",
    "Folder" : "Folder",
    "Images" : "Images",
    "Office documents" : "Office documents",
    "PDF documents" : "PDF documents",
    "Video" : "Video",
    "Custom MIME type" : "Custom MIME type",
    "Custom mimetype" : "Custom mimetype",
    "Select a file type" : "Select a file type",
    "e.g. httpd/unix-directory" : "e.g. httpd/unix-directory",
    "Please enter a valid time span" : "Please enter a valid time span",
    "Files WebDAV" : "Files WebDAV",
    "Custom URL" : "Custom URL",
    "Select a request URL" : "Select a request URL",
    "Android client" : "Android client",
    "iOS client" : "iOS client",
    "Desktop client" : "Desktop client",
    "Thunderbird & Outlook addons" : "Thunderbird & Outlook addons",
    "Custom user agent" : "Custom user agent",
    "Select a user agent" : "Select a user agent",
    "Select groups" : "Select groups",
    "Groups" : "Groups",
    "Type to search for group …" : "Type to search for group …",
    "Select a trigger" : "Select a trigger",
    "At least one event must be selected" : "At least one event must be selected",
    "Add new flow" : "Add new flow",
    "The configuration is invalid" : "The configuration is invalid",
    "Active" : "Active",
    "Save" : "Save",
    "When" : "When",
    "and" : "and",
    "Add a new filter" : "Add a new filter",
    "Cancel" : "Cancel",
    "Delete" : "Delete",
    "Available flows" : "Available flows",
    "For details on how to write your own flow, check out the development documentation." : "For details on how to write your own flow, check out the development documentation.",
    "No flows installed" : "No flows installed",
    "Ask your administrator to install new flows." : "Ask your administrator to install new flows.",
    "More flows" : "More flows",
    "Browse the App Store" : "Browse the App Store",
    "Show less" : "Show less",
    "Show more" : "Show more",
    "Configured flows" : "Configured flows",
    "Your flows" : "Your flows",
    "No flows configured" : "No flows configured",
    "matches" : "matches",
    "does not match" : "does not match",
    "is" : "is",
    "is not" : "is not",
    "File name" : "File name",
    "File MIME type" : "File MIME type",
    "File size (upload)" : "File size (upload)",
    "less" : "less",
    "less or equals" : "less or equals",
    "greater or equals" : "greater or equals",
    "greater" : "greater",
    "Request remote address" : "Request remote address",
    "matches IPv4" : "matches IPv4",
    "does not match IPv4" : "does not match IPv4",
    "matches IPv6" : "matches IPv6",
    "does not match IPv6" : "does not match IPv6",
    "File system tag" : "File system tag",
    "is tagged with" : "is tagged with",
    "is not tagged with" : "is not tagged with",
    "Request URL" : "Request URL",
    "Request time" : "Request time",
    "between" : "between",
    "not between" : "not between",
    "Request user agent" : "Request user agent",
    "Group membership" : "Group membership",
    "is member of" : "is member of",
    "is not member of" : "is not member of"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/workflowengine/l10n/en_GB.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "The given operator is invalid",
    "The given regular expression is invalid" : "The given regular expression is invalid",
    "The given file size is invalid" : "The given file size is invalid",
    "The given tag id is invalid" : "The given tag id is invalid",
    "The given IP range is invalid" : "The given IP range is invalid",
    "The given IP range is not valid for IPv4" : "The given IP range is not valid for IPv4",
    "The given IP range is not valid for IPv6" : "The given IP range is not valid for IPv6",
    "The given time span is invalid" : "The given time span is invalid",
    "The given start time is invalid" : "The given start time is invalid",
    "The given end time is invalid" : "The given end time is invalid",
    "The given group does not exist" : "The given group does not exist",
    "File" : "File",
    "File created" : "File created",
    "File updated" : "File updated",
    "File renamed" : "File renamed",
    "File deleted" : "File deleted",
    "File accessed" : "File accessed",
    "File copied" : "File copied",
    "Tag assigned" : "Tag assigned",
    "Someone" : "Someone",
    "%s created %s" : "%s created %s",
    "%s modified %s" : "%s modified %s",
    "%s deleted %s" : "%s deleted %s",
    "%s accessed %s" : "%s accessed %s",
    "%s renamed %s" : "%s renamed %s",
    "%s copied %s" : "%s copied %s",
    "%1$s assigned %2$s to %3$s" : "%1$s assigned %2$s to %3$s",
    "Operation #%s does not exist" : "Operation #%s does not exist",
    "Entity %s does not exist" : "Entity %s does not exist",
    "Entity %s is invalid" : "Entity %s is invalid",
    "No events are chosen." : "No events are chosen.",
    "Entity %s has no event %s" : "Entity %s has no event %s",
    "Operation %s does not exist" : "Operation %s does not exist",
    "Operation %s is invalid" : "Operation %s is invalid",
    "At least one check needs to be provided" : "At least one check needs to be provided",
    "The provided operation data is too long" : "The provided operation data is too long",
    "Invalid check provided" : "Invalid check provided",
    "Check %s does not exist" : "Check %s does not exist",
    "Check %s is invalid" : "Check %s is invalid",
    "Check %s is not allowed with this entity" : "Check %s is not allowed with this entity",
    "The provided check value is too long" : "The provided check value is too long",
    "Check #%s does not exist" : "Check #%s does not exist",
    "Check %s is invalid or does not exist" : "Check %s is invalid or does not exist",
    "Flow" : "Flow",
    "Nextcloud workflow engine" : "Nextcloud workflow engine",
    "Select a filter" : "Select a filter",
    "Select a comparator" : "Select a comparator",
    "Remove filter" : "Remove filter",
    "Audio" : "Audio",
    "Folder" : "Folder",
    "Images" : "Images",
    "Office documents" : "Office documents",
    "PDF documents" : "PDF documents",
    "Video" : "Video",
    "Custom MIME type" : "Custom MIME type",
    "Select a file type" : "Select a file type",
    "e.g. httpd/unix-directory" : "e.g. httpd/unix-directory",
    "Please enter a valid time span" : "Please enter a valid time span",
    "Files WebDAV" : "Files WebDAV",
    "Custom URL" : "Custom URL",
    "Select a request URL" : "Select a request URL",
    "Android client" : "Android client",
    "iOS client" : "iOS client",
    "Desktop client" : "Desktop client",
    "Thunderbird & Outlook addons" : "Thunderbird & Outlook addons",
    "Custom user agent" : "Custom user agent",
    "Select a user agent" : "Select a user agent",
    "Select groups" : "Select groups",
    "Groups" : "Groups",
    "Type to search for group …" : "Type to search for group …",
    "Select a trigger" : "Select a trigger",
    "At least one event must be selected" : "At least one event must be selected",
    "Add new flow" : "Add new flow",
    "The configuration is invalid" : "The configuration is invalid",
    "Active" : "Active",
    "Save" : "Save",
    "When" : "When",
    "and" : "and",
    "Add a new filter" : "Add a new filter",
    "Cancel" : "Cancel",
    "Delete" : "Delete",
    "Available flows" : "Available flows",
    "For details on how to write your own flow, check out the development documentation." : "For details on how to write your own flow, check out the development documentation.",
    "No flows installed" : "No flows installed",
    "Ask your administrator to install new flows." : "Ask your administrator to install new flows.",
    "More flows" : "More flows",
    "Browse the App Store" : "Browse the App Store",
    "Show less" : "Show less",
    "Show more" : "Show more",
    "Configured flows" : "Configured flows",
    "Your flows" : "Your flows",
    "No flows configured" : "No flows configured",
    "matches" : "matches",
    "does not match" : "does not match",
    "is" : "is",
    "is not" : "is not",
    "File name" : "File name",
    "File MIME type" : "File MIME type",
    "File size (upload)" : "File size (upload)",
    "less" : "less",
    "less or equals" : "less or equals",
    "greater or equals" : "greater or equals",
    "greater" : "greater",
    "Request remote address" : "Request remote address",
    "matches IPv4" : "matches IPv4",
    "does not match IPv4" : "does not match IPv4",
    "matches IPv6" : "matches IPv6",
    "does not match IPv6" : "does not match IPv6",
    "File system tag" : "File system tag",
    "is tagged with" : "is tagged with",
    "is not tagged with" : "is not tagged with",
    "Request URL" : "Request URL",
    "Request time" : "Request time",
    "between" : "between",
    "not between" : "not between",
    "Request user agent" : "Request user agent",
    "Group membership" : "Group membership",
    "is member of" : "is member of",
    "is not member of" : "is not member of",
    "Type to search for group …" : "Type to search for group …"
},
"nplurals=2; plural=(n != 1);");
